==> qt-creator-opensource-src-3.0.0.zip: qt-creator-opensource-src-3.0.0/src/plugins/texteditor/codeassist/igenericproposalmodel.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef IGENERICPROPOSALMODEL_H
#define IGENERICPROPOSALMODEL_H

#include "iassistproposalmodel.h"
#include "assistenums.h"

#include <texteditor/texteditor_global.h>

QT_FORWARD_DECLARE_CLASS(QIcon)

namespace TextEditor {

class IAssistProposalItem;

class TEXTEDITOR_EXPORT IGenericProposalModel : public IAssistProposalModel
{
public:
    IGenericProposalModel();
    virtual ~IGenericProposalModel();

    virtual QIcon icon(int index) const = 0;
    virtual QString detail(int index) const = 0;
    virtual int persistentId(int index) const = 0;
    virtual void removeDuplicates() = 0;
    virtual void filter(const QString &prefix) = 0;
    virtual bool isSortable(const QString &prefix) const = 0;
    virtual void sort(const QString &prefix) = 0;
    virtual bool supportsPrefixExpansion() const = 0;
    virtual QString proposalPrefix() const = 0;
    virtual bool keepPerfectMatch(AssistReason reason) const = 0;
    virtual IAssistProposalItem *proposalItem(int index) const = 0;
};

} // TextEditor

#endif // IGENERICPROPOSALMODEL_H

==> qt-creator-opensource-src-3.1.1.zip: qt-creator-opensource-src-3.1.1/src/plugins/texteditor/codeassist/igenericproposalmodel.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef IGENERICPROPOSALMODEL_H
#define IGENERICPROPOSALMODEL_H

#include "iassistproposalmodel.h"
#include "assistenums.h"

#include <texteditor/texteditor_global.h>

QT_FORWARD_DECLARE_CLASS(QIcon)

namespace TextEditor {

class IAssistProposalItem;

class TEXTEDITOR_EXPORT IGenericProposalModel : public IAssistProposalModel
{
public:
    IGenericProposalModel();
    ~IGenericProposalModel();

    virtual QIcon icon(int index) const = 0;
    virtual QString detail(int index) const = 0;
    virtual int persistentId(int index) const = 0;
    virtual void removeDuplicates() = 0;
    virtual void filter(const QString &prefix) = 0;
    virtual bool isSortable(const QString &prefix) const = 0;
    virtual void sort(const QString &prefix) = 0;
    virtual bool supportsPrefixExpansion() const = 0;
    virtual QString proposalPrefix() const = 0;
    virtual bool keepPerfectMatch(AssistReason reason) const = 0;
    virtual IAssistProposalItem *proposalItem(int index) const = 0;
};

} // TextEditor

#endif // IGENERICPROPOSALMODEL_H
